@@ -11,9 +11,13 @@
 
 from gooddata_metadata_client.model.api_entitlement import ApiEntitlement
 from gooddata_metadata_client.model.assignee_identifier import AssigneeIdentifier
+from gooddata_metadata_client.model.available_assignees import AvailableAssignees
+from gooddata_metadata_client.model.dashboard_permissions import DashboardPermissions
 from gooddata_metadata_client.model.data_source_table_identifier import DataSourceTableIdentifier
 from gooddata_metadata_client.model.dataset_reference_identifier import DatasetReferenceIdentifier
 from gooddata_metadata_client.model.declarative_analytical_dashboard import DeclarativeAnalyticalDashboard
+from gooddata_metadata_client.model.declarative_analytical_dashboard_extension import DeclarativeAnalyticalDashboardExtension
+from gooddata_metadata_client.model.declarative_analytical_dashboard_permission import DeclarativeAnalyticalDashboardPermission
 from gooddata_metadata_client.model.declarative_analytics import DeclarativeAnalytics
 from gooddata_metadata_client.model.declarative_analytics_layer import DeclarativeAnalyticsLayer
 from gooddata_metadata_client.model.declarative_attribute import DeclarativeAttribute
@@ -26,6 +30,7 @@ from gooddata_metadata_client.model.declarative_data_source import DeclarativeDa
 from gooddata_metadata_client.model.declarative_data_source_permission import DeclarativeDataSourcePermission
 from gooddata_metadata_client.model.declarative_data_sources import DeclarativeDataSources
 from gooddata_metadata_client.model.declarative_dataset import DeclarativeDataset
+from gooddata_metadata_client.model.declarative_dataset_sql import DeclarativeDatasetSql
 from gooddata_metadata_client.model.declarative_date_dataset import DeclarativeDateDataset
 from gooddata_metadata_client.model.declarative_fact import DeclarativeFact
 from gooddata_metadata_client.model.declarative_filter_context import DeclarativeFilterContext
@@ -45,7 +50,11 @@ from gooddata_metadata_client.model.declarative_tables import DeclarativeTables
 from gooddata_metadata_client.model.declarative_theme import DeclarativeTheme
 from gooddata_metadata_client.model.declarative_user import DeclarativeUser
 from gooddata_metadata_client.model.declarative_user_group import DeclarativeUserGroup
+from gooddata_metadata_client.model.declarative_user_group_permission import DeclarativeUserGroupPermission
+from gooddata_metadata_client.model.declarative_user_group_permissions import DeclarativeUserGroupPermissions
 from gooddata_metadata_client.model.declarative_user_groups import DeclarativeUserGroups
+from gooddata_metadata_client.model.declarative_user_permission import DeclarativeUserPermission
+from gooddata_metadata_client.model.declarative_user_permissions import DeclarativeUserPermissions
 from gooddata_metadata_client.model.declarative_users import DeclarativeUsers
 from gooddata_metadata_client.model.declarative_users_user_groups import DeclarativeUsersUserGroups
 from gooddata_metadata_client.model.declarative_visualization_object import DeclarativeVisualizationObject
@@ -65,7 +74,10 @@ from gooddata_metadata_client.model.entitlements_request import EntitlementsRequ
 from gooddata_metadata_client.model.entity_identifier import EntityIdentifier
 from gooddata_metadata_client.model.generate_ldm_request import GenerateLdmRequest
 from gooddata_metadata_client.model.grain_identifier import GrainIdentifier
+from gooddata_metadata_client.model.granted_permission import GrantedPermission
 from gooddata_metadata_client.model.granularities_formatting import GranularitiesFormatting
+from gooddata_metadata_client.model.hierarchy_object_identification import HierarchyObjectIdentification
+from gooddata_metadata_client.model.identifier_duplications import IdentifierDuplications
 from gooddata_metadata_client.model.json_api_analytical_dashboard_in import JsonApiAnalyticalDashboardIn
 from gooddata_metadata_client.model.json_api_analytical_dashboard_in_attributes import JsonApiAnalyticalDashboardInAttributes
 from gooddata_metadata_client.model.json_api_analytical_dashboard_in_document import JsonApiAnalyticalDashboardInDocument
@@ -74,6 +86,9 @@ from gooddata_metadata_client.model.json_api_analytical_dashboard_out import Jso
 from gooddata_metadata_client.model.json_api_analytical_dashboard_out_document import JsonApiAnalyticalDashboardOutDocument
 from gooddata_metadata_client.model.json_api_analytical_dashboard_out_includes import JsonApiAnalyticalDashboardOutIncludes
 from gooddata_metadata_client.model.json_api_analytical_dashboard_out_list import JsonApiAnalyticalDashboardOutList
+from gooddata_metadata_client.model.json_api_analytical_dashboard_out_meta import JsonApiAnalyticalDashboardOutMeta
+from gooddata_metadata_client.model.json_api_analytical_dashboard_out_meta_access_info import JsonApiAnalyticalDashboardOutMetaAccessInfo
+from gooddata_metadata_client.model.json_api_analytical_dashboard_out_meta_origin import JsonApiAnalyticalDashboardOutMetaOrigin
 from gooddata_metadata_client.model.json_api_analytical_dashboard_out_relationships import JsonApiAnalyticalDashboardOutRelationships
 from gooddata_metadata_client.model.json_api_analytical_dashboard_out_relationships_analytical_dashboards import JsonApiAnalyticalDashboardOutRelationshipsAnalyticalDashboards
 from gooddata_metadata_client.model.json_api_analytical_dashboard_out_relationships_dashboard_plugins import JsonApiAnalyticalDashboardOutRelationshipsDashboardPlugins
@@ -99,6 +114,7 @@ from gooddata_metadata_client.model.json_api_attribute_out_attributes import Jso
 from gooddata_metadata_client.model.json_api_attribute_out_document import JsonApiAttributeOutDocument
 from gooddata_metadata_client.model.json_api_attribute_out_includes import JsonApiAttributeOutIncludes
 from gooddata_metadata_client.model.json_api_attribute_out_list import JsonApiAttributeOutList
+from gooddata_metadata_client.model.json_api_attribute_out_meta import JsonApiAttributeOutMeta
 from gooddata_metadata_client.model.json_api_attribute_out_relationships import JsonApiAttributeOutRelationships
 from gooddata_metadata_client.model.json_api_attribute_out_relationships_dataset import JsonApiAttributeOutRelationshipsDataset
 from gooddata_metadata_client.model.json_api_attribute_out_relationships_default_view import JsonApiAttributeOutRelationshipsDefaultView
@@ -182,6 +198,7 @@ from gooddata_metadata_client.model.json_api_dataset_out import JsonApiDatasetOu
 from gooddata_metadata_client.model.json_api_dataset_out_attributes import JsonApiDatasetOutAttributes
 from gooddata_metadata_client.model.json_api_dataset_out_attributes_grain_inner import JsonApiDatasetOutAttributesGrainInner
 from gooddata_metadata_client.model.json_api_dataset_out_attributes_reference_properties_inner import JsonApiDatasetOutAttributesReferencePropertiesInner
+from gooddata_metadata_client.model.json_api_dataset_out_attributes_sql import JsonApiDatasetOutAttributesSql
 from gooddata_metadata_client.model.json_api_dataset_out_document import JsonApiDatasetOutDocument
 from gooddata_metadata_client.model.json_api_dataset_out_includes import JsonApiDatasetOutIncludes
 from gooddata_metadata_client.model.json_api_dataset_out_list import JsonApiDatasetOutList
@@ -272,6 +289,7 @@ from gooddata_metadata_client.model.json_api_theme_out_with_links import JsonApi
 from gooddata_metadata_client.model.json_api_theme_patch import JsonApiThemePatch
 from gooddata_metadata_client.model.json_api_theme_patch_document import JsonApiThemePatchDocument
 from gooddata_metadata_client.model.json_api_user_group_in import JsonApiUserGroupIn
+from gooddata_metadata_client.model.json_api_user_group_in_attributes import JsonApiUserGroupInAttributes
 from gooddata_metadata_client.model.json_api_user_group_in_document import JsonApiUserGroupInDocument
 from gooddata_metadata_client.model.json_api_user_group_in_relationships import JsonApiUserGroupInRelationships
 from gooddata_metadata_client.model.json_api_user_group_in_relationships_parents import JsonApiUserGroupInRelationshipsParents
@@ -363,9 +381,18 @@ from gooddata_metadata_client.model.list_links_all_of import ListLinksAllOf
 from gooddata_metadata_client.model.object_links import ObjectLinks
 from gooddata_metadata_client.model.object_links_container import ObjectLinksContainer
 from gooddata_metadata_client.model.parameter import Parameter
+from gooddata_metadata_client.model.pdm_ldm_request import PdmLdmRequest
+from gooddata_metadata_client.model.pdm_sql import PdmSql
+from gooddata_metadata_client.model.permissions_for_assignee import PermissionsForAssignee
 from gooddata_metadata_client.model.platform_usage import PlatformUsage
 from gooddata_metadata_client.model.platform_usage_request import PlatformUsageRequest
 from gooddata_metadata_client.model.reference_identifier import ReferenceIdentifier
 from gooddata_metadata_client.model.resolve_settings_request import ResolveSettingsRequest
+from gooddata_metadata_client.model.resolved_setting import ResolvedSetting
+from gooddata_metadata_client.model.sql_column import SqlColumn
+from gooddata_metadata_client.model.user_assignee import UserAssignee
+from gooddata_metadata_client.model.user_group_assignee import UserGroupAssignee
 from gooddata_metadata_client.model.user_group_identifier import UserGroupIdentifier
+from gooddata_metadata_client.model.user_group_permission import UserGroupPermission
+from gooddata_metadata_client.model.user_permission import UserPermission
 from gooddata_metadata_client.model.workspace_identifier import WorkspaceIdentifier
